pub struct AssociativeSubalgebraRecord<H>where
H: HostTypes,{
pub subalgebra_ref_handle: AssociativeSubalgebraHandle<H>,
pub associator_ref_handle: AssociatorTripleHandle<H>,
/* private fields */
}Expand description
Phase 8 (orphan-closure) — typed record for AssociativeSubalgebra<H>.
Carries a field per functional accessor of the trait. Object
fields hold {Range}Handle<H>; iterate via the Resolved wrapper
chain-resolver methods.
Fields
subalgebra_ref_handle: AssociativeSubalgebraHandle<H>associator_ref_handle: AssociatorTripleHandle<H>Trait Implementations
Sourceimpl<H> Clone for AssociativeSubalgebraRecord<H>
impl<H> Clone for AssociativeSubalgebraRecord<H>
Sourcefn clone(&self) -> AssociativeSubalgebraRecord<H>
fn clone(&self) -> AssociativeSubalgebraRecord<H>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<H> Debug for AssociativeSubalgebraRecord<H>
impl<H> Debug for AssociativeSubalgebraRecord<H>
Sourceimpl<H> Hash for AssociativeSubalgebraRecord<H>
impl<H> Hash for AssociativeSubalgebraRecord<H>
Sourceimpl<H> PartialEq for AssociativeSubalgebraRecord<H>
impl<H> PartialEq for AssociativeSubalgebraRecord<H>
Sourcefn eq(&self, other: &AssociativeSubalgebraRecord<H>) -> bool
fn eq(&self, other: &AssociativeSubalgebraRecord<H>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<H> Eq for AssociativeSubalgebraRecord<H>
impl<H> StructuralPartialEq for AssociativeSubalgebraRecord<H>where
H: HostTypes,