pub struct ConvergenceLevelRecord<H>where
H: HostTypes,{
pub algebra_dimension: u64,
pub betti_signature: &'static <H as HostTypes>::HostString,
pub fiber_type_handle: HopfFiberHandle<H>,
pub characteristic_identity: &'static <H as HostTypes>::HostString,
pub level_name: &'static <H as HostTypes>::HostString,
/* private fields */
}Expand description
Phase 8 (orphan-closure) — typed record for ConvergenceLevel<H>.
Carries a field per functional accessor of the trait. Object
fields hold {Range}Handle<H>; iterate via the Resolved wrapper
chain-resolver methods.
Fields
algebra_dimension: u64betti_signature: &'static <H as HostTypes>::HostStringfiber_type_handle: HopfFiberHandle<H>characteristic_identity: &'static <H as HostTypes>::HostStringlevel_name: &'static <H as HostTypes>::HostStringTrait Implementations
Sourceimpl<H> Clone for ConvergenceLevelRecord<H>
impl<H> Clone for ConvergenceLevelRecord<H>
Sourcefn clone(&self) -> ConvergenceLevelRecord<H>
fn clone(&self) -> ConvergenceLevelRecord<H>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<H> Debug for ConvergenceLevelRecord<H>
impl<H> Debug for ConvergenceLevelRecord<H>
Sourceimpl<H> Hash for ConvergenceLevelRecord<H>
impl<H> Hash for ConvergenceLevelRecord<H>
Sourceimpl<H> PartialEq for ConvergenceLevelRecord<H>
impl<H> PartialEq for ConvergenceLevelRecord<H>
Sourcefn eq(&self, other: &ConvergenceLevelRecord<H>) -> bool
fn eq(&self, other: &ConvergenceLevelRecord<H>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<H> Eq for ConvergenceLevelRecord<H>
impl<H> StructuralPartialEq for ConvergenceLevelRecord<H>where
H: HostTypes,