pub struct HopfFiberRecord<H>where
H: HostTypes,{
pub fiber_dimension: u64,
pub total_space: &'static <H as HostTypes>::HostString,
pub base_space: &'static <H as HostTypes>::HostString,
pub fiber_sphere: &'static <H as HostTypes>::HostString,
/* private fields */
}Expand description
Phase 8 (orphan-closure) — typed record for HopfFiber<H>.
Carries a field per functional accessor of the trait. Object
fields hold {Range}Handle<H>; iterate via the Resolved wrapper
chain-resolver methods.
Fields
fiber_dimension: u64total_space: &'static <H as HostTypes>::HostStringbase_space: &'static <H as HostTypes>::HostStringfiber_sphere: &'static <H as HostTypes>::HostStringTrait Implementations
Sourceimpl<H> Clone for HopfFiberRecord<H>
impl<H> Clone for HopfFiberRecord<H>
Sourcefn clone(&self) -> HopfFiberRecord<H>
fn clone(&self) -> HopfFiberRecord<H>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<H> Debug for HopfFiberRecord<H>
impl<H> Debug for HopfFiberRecord<H>
Sourceimpl<H> Hash for HopfFiberRecord<H>
impl<H> Hash for HopfFiberRecord<H>
Sourceimpl<H> PartialEq for HopfFiberRecord<H>
impl<H> PartialEq for HopfFiberRecord<H>
Sourcefn eq(&self, other: &HopfFiberRecord<H>) -> bool
fn eq(&self, other: &HopfFiberRecord<H>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<H> Eq for HopfFiberRecord<H>
impl<H> StructuralPartialEq for HopfFiberRecord<H>where
H: HostTypes,